//The current file is auto-generated by script: generate_codec_ver.sh
#ifndef CODEC_VER_H
#define CODEC_VER_H

#include "codec_app_def.h"

static const OpenH264Version g_stCodecVersion  = {1, 8, 0, 1806};
static const char* const g_strCodecVer  = "OpenH264 version:1.8.0.1806";

#define OPENH264_MAJOR (1)
#define OPENH264_MINOR (8)
#define OPENH264_REVISION (0)
#define OPENH264_RESERVED (1806)

#endif  // CODEC_VER_H
